# In order to generate the SchemaSpy documentation of the BETYdb database schema
# (rake task "bety:dbdocs"), you have to specify an output directory and the
# locations of the Java executatable and the required Jar files.  This may
# either be done by creating a configuration file "schemaSpyConfig.rb" in this
# directory or by adding the required settings to the YAML file
# config/application.yml.  Specifying settings in the YAML file is now the
# preferred method.


# TYPICAL CONFIGURATION FOR ORDINARY USAGE:

# @java should be set to the command for invoking java.  If needed, this could
# be prefixed by environment variable settings, e.g. @java =
# "CLASSPATH=~/java_class_files java" or by calls to "module" in order to set up
# the environment.  On ebi-forecast we use
#
#     @java = "module load java/1.8.0_45; module load graphviz/2.2.1; java"
#
# so that the correct versions of java and graphviz are used.
#
@java = "java"

# Download schemaSpy.jar from
# https://www.dropbox.com/s/j50hk7cbqw7680u/schemaSpy.jar?dl=0 and place the
# downloaded file in some accessible location.  (The @schemaSpy variable should
# be set to that location.)  This is a customized version of SchemaSpy made
# especially for the BETYdb Rails app.  Java SE 8 is required to build the
# documentation when using this version of the SchemaSpy Jar file.
#
@schemaSpy = "~/Applications/SchemaSpy/schemaSpy.jar"

# If you don't have a copy of the Postgres JDBC driver, it may be downloaded
# from https://jdbc.postgresql.org/download.html.  Version 9.3-1103 JDBC 41 is
# compatible both with PostgreSQL 9.3 and with Java SE 8.
#
@driver = "~/Applications/SchemaSpy/postgresql-9.3-1103.jdbc41.jar"

# To have the files generated by the customized version of SchemaSpy put output
# files in the correct locations in the Rails directory tree, the output
# directory should be set to the Rails root directory.  This is accomplished by
# the following setting:
#
@outdir = "."

# SchemaSpy produces some files in the root directory not used by the Rails
# app.  If you are running the version of SchemaSpy for BETYdb, you probably
# want to remove them:
#
@remove_root_dir_files = true



# CONFIGURATION FOR USING THE ORIGINAL (NON-CUSTOMIZED) VERSION OF SchemaSpy.
# This may in particular be useful for developers.

# Download the SchemaSpy Jar file from
# http://sourceforge.net/projects/schemaspy/files/schemaspy/
#
# @schemaSpy = "~/Applications/SchemaSpy/schemaSpy_5.0.0.jar"
 
# The same driver as above may be used.  Since this version of SchemaSpy is
# compatible with Java 5 and later, you could use jdbc3 or jdbc4 if you are
# using Java 5 or Java 6.  (But upgrading to the latest version of Java is
# recommended.)
#
# @driver = "~/Applications/SchemaSpy/postgresql-9.3-1103.jdbc3.jar"

# Use something other that the Rails root directory if you are not using the
# customized version of SchemaSpy.  Otherwise the generated files will pollute
# your Rails root directory:
#
# @outdir = "public/db_docs" # This is the setting we use on ebi-forecast for
#                            # the version of BETYdb at www.betydb.org, which
#                            # makes the docs viewable at
#                            # www.betydb.org/db_docs/index.html.
